# frozen_string_literal: true

module Ella
  # The nature of Sinatra and Puma means that the config.ru file must initialize
  # certain files. To make Ella work, this must be updated before the server is
  # started.
  # This is essentially a hack to deal with the fact that Sinatra was designed,
  # apparently, to run one single controller file.
  class RackfileGenerator < Generator
    def run(mode = 'development')
      @mode = mode
      Ella.find_root
      Log.info('Generating rack.ru...')
      write
    end

    private

    def main_project_file_content
      Ella.abort('Warning: "main.rb" not found. Aborting.') unless File.exist?('main.rb')
      @main_file_content ||= File.open('main.rb').read
      @main_file_content
    end

    # This looks bad, but adds a good deal of flexibility for the user, should they ever be
    # desperate to change the project name of an already-generated project.
    def project_name
      raw_project_name = main_project_file_content.scan(/class (.*) < Ella::Controller/).first.first
      NameFormatter.new(raw_project_name)
    end

    def get_controllers
      @controllers = Dir.entries('controllers').select { |e| e =~ /\.rb$/ }.map { |e| e[0..-4] }
    rescue SystemCallError
      make_directory('controllers')
      retry
    end

    def get_models
      @models = Dir.entries('models').select { |e| e =~ /\.rb$/ }.map { |e| e[0..-4] }
    rescue SystemCallError
      make_directory('models')
      retry
    end

    def require_all_models
      get_models
      @models && @models.map { |e| "require_relative 'models/#{e}'" }.join("\n")
    end

    def require_all_controllers
      get_controllers
      @controllers && @controllers.map { |e| "require_relative 'controllers/#{e}'" }.join("\n")
    end

    def use_all_controllers
      @controllers && @controllers.map { |e| "use #{e.capitalize}Controller" }.join("\n")
    end

    def write
      File.open('rack.ru', 'w') { |f| f.puts(generate) }
    end

    def generate
      "# WARNING: This file is autmatically generated by Ella, and may be rewritten\n" \
        "# at any time. Any changes you make here may vanish. The appropriate place for\n" \
        "# general changes is 'main.rb', which will never be overritten by Ella.)\n" \
        "require 'ella'\n\n" \
        "require './main'\n\n" \
        "#{require_all_models}\n" \
        "#{require_all_controllers}\n\n" \
        "#{use_all_controllers}\n\n" \
        "run #{project_name.pascal_case}\n"
    end
  end
end
